<?php

App::uses('BaseMigrationModelUtil', 'EvMigrationUtil.Lib');

class MenuMigrationModelUtil extends BaseMigrationModelUtil {

/**
 * Attempts to find a menu item based on its parent. If not found it is created under that parent.
 *
 * @param array $conditions       The conditions to match to be an existing record
 * @param array $parentConditions The conditions the parent must match to be the parent. If this is not found, inserting will fail.
 * @param array $data             The data to insert if it doesn't already exist
 * @return int|bool The inserted id on success, false on fail.
 */
	public function createOnceWithParent($conditions, $parentConditions, $data) {
		// Check if the parent record exists
		$parentId = $this->Model->field($this->Model->alias . '.id', $parentConditions);

		if (!empty($parentId)) {

			$data = Hash::merge($data, [
				$this->Model->alias => [
					'parent_id' => $parentId
				]
			]);

			$conditions = Hash::merge($conditions, [
				$this->Model->alias . '.parent_id' => $parentId
			]);

			// Do the usual now we've identified the parent
			return $this->createOnce($conditions, $data);
		}

		return false;
	}

/**
 * Deletes the records met by the given conditions including conditions for the parent
 *
 * @param array $conditions       Conditions array to delete a record by
 * @param array $parentConditions Conditions array to identify the parent
 * @param array $cascade          Delete dependants
 * @param array $callbacks        Trigger callbacks
 * @return bool                   Returns true if the delete suceeds or the record doesn't exists
 */
	public function deleteAllWithParent($conditions, $parentConditions, $cascade = true, $callbacks = false) {
		$parentId = $this->Model->field($this->Model->alias . '.id', $parentConditions);

		if (!empty($parentId)) {
			$conditions = Hash::merge($conditions, [
				$this->Model->alias . '.parent_id' => $parentId
			]);
			// Do the usual now we've identified the parent
			return $this->deleteAll($conditions, $cascade, $callbacks);
		}

		return true;
	}

}
